@@ -19,7 +19,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         QtGui.QMainWindow.__init__(self, parent)
         self.setupUi(self)
         self.themeDir="/home/user/MyDocs/Nclocktheme/"
-        self.sysThemeDir="theme/"
+        self.sysThemeDir="/home/opt/nclock/theme/"
         self.theme=["clock-drop-shadow.svg", 
                                "clock-face.svg", 
                                "clock-face-shadow.svg", 
